<html>
	<head>
		<title>Playwire Video API Test - Video Delete</title>
	</head>
<body>
<pre>
<?php
	require_once('../common.php');
	if (empty($api_token)) {
		showAPITokenForm();
	} else {
		require_once('../class.playwire.php');

		$playwire = new Playwire($api_token);

		$id = $_GET['id'];
		if ($id) {
			try {
				$playwire->deleteVideo($id);
				echo "Successfully deleted video with id " . $id;
			} catch (PlaywireException $exception) {
				echo "Had an exception: " . $exception->getMessage();
			}
		} else
			echo "Error: No video ID provided.";
	}
?>
</pre>
</body>
</html>
